[![Tests](https://github.com/zgallagher08/python3-template/workflows/Tests/badge.svg)](https://github.com/zgallagher08/python3-template/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/zgallagher08/python3-template/branch/master/graph/badge.svg)](https://codecov.io/gh/zgallagher08/python3-template)
[![PyPI](https://img.shields.io/pypi/v/python3-template.svg)](https://pypi.org/project/python3-template/)

# python3-template
Implementation of Hypermodern Python repo (https://cjolowicz.github.io/posts/hypermodern-python-01-setup/)
